#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
H1, L1, V1 sensitivity curves and ranges during O3b run
"""

import numpy as np
from numpy import *

import matplotlib
matplotlib.use('Agg')
matplotlib.rcParams['text.usetex'] = True
matplotlib.rcParams['font.size'] = 9
matplotlib.rcParams['savefig.dpi'] = 300
matplotlib.rcParams['text.latex.preamble'] = r'\usepackage{amsmath}'
matplotlib.rcParams['legend.fontsize'] = 9
from matplotlib import pyplot
pyplot.rc('axes', axisbelow=True)

colors = {'L1': '#4ba6ff', 'H1': '#ee0000', 'V1': '#9b59b6'}

# Import V1 sensitivity
fv = 'O3-V1-1265246178_sensitivity_strain_asd.txt'
v1 = np.loadtxt(fv)

# Import H1 sensitivity (C01_CLEAN_SUB60HZ); data from https://dcc.ligo.org/LIGO-G2100674
fh = 'O3-H1-C01_CLEAN_SUB60HZ-1262197260.0_sensitivity_strain_asd.txt'
h1 = np.loadtxt(fh) 

# Import L1 sensitivity (C01_CLEAN_SUB60HZ); data from https://dcc.ligo.org/LIGO-G2100675
fl = 'O3-L1-C01_CLEAN_SUB60HZ-1262141640.0_sensitivity_strain_asd.txt'
l1 = np.loadtxt(fl) 

# Sensitivity curves
fig = pyplot.figure(figsize=(3.375,3))
pyplot.loglog(h1[:,0], h1[:,1], label=r'$\mathrm{LIGO}\,\mathrm{Hanford}$', color=colors['H1'], linewidth=1, alpha=0.7)
pyplot.loglog(l1[:,0], l1[:,1], label=r'$\mathrm{LIGO}\,\mathrm{Livingston}$', color=colors['L1'], linewidth=1, alpha=0.7)
pyplot.loglog(v1[:,0], v1[:,1], label=r'$\mathrm{Virgo}$', color=colors['V1'], linewidth=1, alpha=0.7)
pyplot.legend(loc=(0.12, 0.73),frameon=False)
pyplot.xlabel(r'$\mathrm{Frequency}\,\mathrm{[Hz]}$')
pyplot.ylabel(r'$\mathrm{Strain}\,[1/\sqrt{\mathrm{Hz}}]$')
pyplot.xlim([10, 4000])
pyplot.ylim(1e-24, 1e-18)
pyplot.grid(False)
ax = pyplot.gca()
ax.xaxis.set_ticks_position('both')
ax.yaxis.set_ticks_position('both')
fig.tight_layout()
pyplot.savefig('figure_2.pdf')
